import { languages } from 'monaco-editor/esm/vs/editor/editor.api.js';
import { registerMarkerDataProvider } from 'monaco-marker-data-provider';
import { createWorkerManager } from 'monaco-worker-manager';
import { createCodeActionProvider, createDocumentFormattingProvider, createMarkerDataProvider, } from './languageFeatures.js';
/**
 * Configure monaco-unified.
 *
 * @param monaco - The `monaco-editor` module to use.
 * @param options - Options to configure `monaco-unified`.
 * @returns A disposable
 */
export function configureMonacoUnified(monaco, options) {
    const workerManager = createWorkerManager(monaco, {
        label: options.label,
        moduleId: options.label,
        createData: options.configuration,
    });
    let markerDataProvider;
    const disposables = [workerManager];
    if (options.formatting !== false) {
        disposables.push(languages.registerDocumentFormattingEditProvider(options.languageSelector, createDocumentFormattingProvider(workerManager.getWorker)));
    }
    if (options.validation !== false) {
        disposables.push(languages.registerCodeActionProvider(options.languageSelector, createCodeActionProvider()));
        markerDataProvider = registerMarkerDataProvider(monaco, options.languageSelector, createMarkerDataProvider(monaco, workerManager.getWorker));
    }
    return {
        dispose() {
            markerDataProvider === null || markerDataProvider === void 0 ? void 0 : markerDataProvider.dispose();
            for (const disposable of disposables) {
                disposable.dispose();
            }
        },
        reconfigure(configuration) {
            workerManager.updateCreateData(configuration);
            if (markerDataProvider) {
                markerDataProvider.dispose();
                markerDataProvider = registerMarkerDataProvider(monaco, options.languageSelector, createMarkerDataProvider(monaco, workerManager.getWorker));
            }
        },
    };
}
